import { PluginFunction, PluginValidateFn } from '@graphql-codegen/plugin-helpers';
export interface SchemaASTConfig {
    /**
     * @name includeDirectives
     * @type boolean
     * @description Include directives to Schema output.
     * @default false
     *
     * @example
     * ```yml
     * schema:
     *   - './src/schema.graphql'
     * generates:
     *   path/to/file.graphql:
     *     plugins:
     *       - schema-ast
     *     config:
     *       includeDirectives: true
     * ```
     */
    includeDirectives?: boolean;
    /**
     * @name commentDescriptions
     * @type boolean
     * @description Set to true in order to print description as comments (using # instead of """)
     * @default false
     *
     * @example
     * ```yml
     * schema: http://localhost:3000/graphql
     * generates:
     *   schema.graphql:
     *     plugins:
     *       - schema-ast
     *     config:
     *       commentDescriptions: true
     * ```
     */
    commentDescriptions?: boolean;
    federation?: boolean;
}
export declare const plugin: PluginFunction<SchemaASTConfig>;
export declare const validate: PluginValidateFn<any>;
